### A Pluto.jl notebook ###
# v0.19.27

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ 3eeeedf8-d228-4178-bfc5-710f46649c2a
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoTeachingTools
	using CSV, DataFrames, Dates, PeriodicalDates, StatsBase
	using NLsolve
end

# ╔═╡ 1f1076c3-5aca-4037-8d45-6a23872ceda4
function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsivity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
end;

# ╔═╡ 680433b3-98f7-437c-9026-9533c9b4f61e
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
<title>Macroeconomia</title>
<subtitle>Teste Final Modelo</subtitle>
<semester>Licenciatura em Gestão<br>1º Semestre 2022-23</semester>
<author>Vivaldo Mendes, Luís Clemente-Casinhas, Ricardo Gouveia-Mendes</author>
"""

# ╔═╡ 66e21396-7e88-4913-b3ce-b6b4f5f9656a
@bind nome TextField(66, placeholder="Nome")

# ╔═╡ efc03349-cad1-482c-a4ee-d410a66b36e8
@bind numero TextField(placeholder="Número de aluno")

# ╔═╡ 7241544e-5d6d-4897-bae3-843dc1eb170e
md"""
> O teste é composto por 40 questões de **escolha múltipla**. Em cada questão, selecione **a alternativa correta**, a menos que lhe seja indicada outra coisa.
>
> Cada pergunta de escolha múltipla tem a cotação de **0.5 pontos**.
>
> Respostas **erradas descontam -0.125 pontos**.
>
> É esperado que este teste modelo **demore apenas 1h a responder**.
>
> ---
>
> **NOTA:** O teste a sério conterá 50 perguntas e o tempo de resolução será de 1h30.
"""

# ╔═╡ 4ad6bdf1-3029-43e5-9b0f-cff6525ffe94
md"---"

# ╔═╡ ca0e61f0-f955-11ed-00af-1f63977dd3de
md"""
Se existir um choque positivo sobre a AS (ou seja, se $\rho$ diminuir), este facto irá:

**a)** Provocar um deslocamento da curva AS para a direita (ou seja, para baixo).

**b)** Provocar um deslocamento da curva AS para a esquerda (ou seja, para cima).

**c)** Provocar um deslocamento ao longo da curva AS.

**d)** Manter a curva AS totalmente inalterada.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 584268fb-7d05-4ec1-aced-acdd66e7d7f4
@bind q01 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5fd57b29-069d-4a2e-872e-bb9b9bbe1ff0
md"""
Um dos fenómenos que pode levar a uma deslocação para cima da Curva de Phillips é:

**a)** Uma diminuição do preço do pretróleo.

**b)** Um aumento da taxa de desemprego.

**c)** Um aumento da taxa de desemprego natural.

**d)** Um aumento da inflação esperada.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 5117e0b7-07f2-440e-9edf-098dc77b128f
@bind q02 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 7f860aaa-b1bc-4ed7-a9aa-1b07e07cadc3
md"""
No longo prazo:

**a)** Aumentos da taxa de inflação estão associados com o aumento do produto.

**b)** A procura agregada é representada por uma curva vertical em que a inflação é igual à inflação esperada.

**c)** O ajustamento dos preços é mais rígido do que no curto prazo.

**d)** A quantidade de produto que uma economia consegue produzir é determinada por variáveis como capital, trabalho e tecnologia.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 4cf1f4da-e5e3-4fa8-a15c-41bdcc8d5c78
@bind q03 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5265edb5-ec8b-434c-bef2-1b45dbd143b7
let
	output = 0:1:16
	PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
	trace7_24 = scatter(;x =output, y = PC, 
					name = "AS", line_color = "Blue", mode = "lines", 
					line_width="2.0")		
	trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="blue",	
					textfont = attr(family="sans serif", size=16, color="black"))
	trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")	
	layout7_25 = Layout(;
					title_text = "The AS curve",
					title_x = 0.5,
        			yaxis_title = "Rate of Inflation",
					yaxis_zeroline= false,
					hovermode="x",
        			xaxis_range = [6.0, 14.0],
        			xaxis_title = "GDP (trillion dollars)",
					xaxis_zeroline= false,
        			yaxis_range=[2.0, 4.0], 
        			titlefont_size=18)	
	p7_25=Plot([trace7_49, trace7_24, trace7_25], layout7_25)
end

# ╔═╡ 29889baf-6d1a-45e7-8af4-ea9238715c47
md"""
Sabendo que o PIB potencial (Yp) é igual a 10 triliões de dólares (conforme figura acima), a economia desloca-se do ponto 1 para 3 devido ao facto de:

**a)** A economia ter entrado num “boom” económico, o que levou a uma redução na taxa de inflação.

**b)** A economia ter entrado num “boom” económico, o que levou a um aumento na taxa de inflação.

**c)** A economia ter entrado numa recessão económica, o que levou a uma redução na taxa de inflação.

**d)** A economia ter entrado numa recessão económica, o que levou a um aumento na taxa de inflação.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 617482da-379f-448a-b021-8a2d0a80416e
@bind q04 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 8a796898-03c2-4b93-98d8-bb95ae46e45c
md"""
A Lei de Okun representa:

**a)** Uma relação positiva entre a taxa de desemprego cíclico e o output-gap.

**b)** Uma relação negativa entre a taxa de desemprego e o PIB potencial.

**c)** Uma relação positiva entre a taxa de desemprego natural e o PIB.

**d)** Uma relação negativa entre a taxa de desemprego cíclico e o output-gap.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ a8f403a7-6d38-435e-8307-22388809b267
@bind q05 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c0147dfb-3abc-4ef3-9d3d-215cf69deb02
let
	output = 0:1:16
	PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
	trace7_24 = scatter(;x =output, y = PC, 
					name = "AS", line_color = "Blue", mode = "lines", 
					line_width="2.5")		
	trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="blue",	
					textfont = attr(family="sans serif", size=16, color="black"))
	trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")	
	trace7_41 = scatter(; x = [8.0, 10.0, 12.0], y = [3.0, 3.5 , 4.0], text = ["2'", "1'" , "3'"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="Red",	
					textfont = attr(family="sans serif", size=16, color="black"))
	layout7_25 = Layout(;
					title_text = "The AS curve",
					title_x = 0.5,
        			yaxis_title = "Rate of Inflation",
					yaxis_zeroline= false,
					hovermode="x",
        			xaxis_range = [6.0, 14.0],
        			xaxis_title = "GDP (trillion dollars)",
					xaxis_zeroline= false,
        			yaxis_range=[2.0, 4.2], 
        			titlefont_size=18)
	p7_25=Plot([trace7_49, trace7_24, trace7_25, trace7_41], layout7_25)
end

# ╔═╡ 5c40e68a-da32-4bd0-af8e-c3141318d0a7
md"""
Na figura acima, como justifica o deslocamento da curva AS do ponto 2 para 2’?

**a)** Um choque positivo sobre a AS em $-0.5$ pontos percentuais.

**b)** Uma subida do PIB em 2 triliões de dólares.

**c)** Uma descida do PIB em 2 triliões de dólares.

**d)** Um choque negativo sobre a AS em $+0.5$ pontos percentuais.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ a02a491a-ec0f-4ef9-b7c5-e31194f43c8c
@bind q06 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c0109b03-2c2f-4d93-b74c-b643c986f545
md"""
Um dos fenómenos que pode levar a uma deslocação ao longo da Curva de Phillips é:

**a)** Uma diminuição do preço do pretróleo.

**b)** Um aumento do custo da energia.

**c)** Uma diminuição da taxa de desemprego.

**d)** Um aumento da inflação esperada.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 6925cd02-56f1-48c7-9b02-c3538e101f4d
@bind q07 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b46aa2bf-8576-44f4-b056-59b5edd8c3dc
md"""
Se existir um choque positivo sobre a AS (ou seja, se $\rho$ diminuir), este facto irá:

**a)** Provocar um aumento da taxa de inflação $(\pi)$, para qualquer nível do PIB $(Y)$.

**b)** Provocar um aumento da taxa de inflação $(\pi)$, bem como um aumento do PIB $(Y)$.

**c)** Manter a taxa de inflação $(\pi)$ e o PIB $(Y)$ inalterados.

**d)** Provocar uma diminuição da taxa de inflação $(\pi)$, para qualquer nível do PIB $(Y)$.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 8a0cf087-7aff-4a17-863e-ee39015ce8a8
@bind q08 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 9f9e760d-c7d7-420e-8ac2-cf6f26ee837b
md"""
De acordo com o mecanismo de auto-correção, após um choque negativo sobre a procura agregada, como regressa o PIB ao valor do PIB potencial?

**a)** O choque negativo sobre a procura faz o produto agregado aumentar para cada nível da taxa de inflação, promovendo um hiato do produto (output gap) positivo, o que faz a inflação aumentar.

**b)** A inflação esperada diminui, deslocando a curva da oferta agregada de curto prazo para baixo e ao longo da nova curva da procura agregada.

**c)** Inflação mais baixa leva a uma resposta automática do Banco de Central aumentando a taxa de juro real, estimulando a despesa planeada, aumentando o produto agregado e diminuindo o hiato do produto (output gap).

**d)** O choque negativo sobre a procura faz o produto agregado aumentar para cada nível da taxa de inflação, promovendo um hiato do produto (output gap) negativo, o que faz a inflação diminuir.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 19e73b89-d4f1-4e82-8ae7-5db98ab7e8c7
@bind q09 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 70e53de6-c41a-472e-9140-dfcdf28598c9
md"""
Um choque permanente positivo na oferta agregada:

**a)** Torna a economia menos eficiente.

**b)** Promove aumentos da taxa de inflação.

**c)** Diminui o produto agregado no longo prazo.

**d)** Pode ser causado pela adoção de regulamentações imprudentes.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 7a93da9a-3380-46f9-944e-83c5ed800c55
@bind q10 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 649703b9-c02b-4ee0-955a-e79abb826988
md"""
O estouro da “bolha tecnológica” de 2000, os ataques terroristas de 2001 e os escândalos corporativos de 2001 e 2002 tiveram efeitos qualitativos semelhantes na economia. Selecione o cenário expectável de ter acontecido.

**a)** A despesa privada terá diminuido deslocando a curva AD para a direita.

**b)** A produto agregado terá diminuído abaixo do potencial, e o mecanismo de autocorreção terá diminuido a taxa de desemprego até se atingir o seu nível mais reduzido (por volta de 2004).

**c)** A despesa privada terá aumentado deslocando a curva AD para a esquerda.

**d)** A produto agregado terá aumentado acima do potencial, e o mecanismo de autocorreção terá aumentado a taxa de desemprego até se atingir o seu nível mais elevado (por volta de 2004).

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 06d66a09-5a55-4a00-b024-6bf84e2f77ad
@bind q11 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ec48a6a7-1565-4075-a933-d029197c6922
md"""
![](https://vivaldomendes.org/images/Tests/oil_prices.png)
"""

# ╔═╡ 0183c27d-9e10-4511-95df-067259f0036a
md"""
Desde o verão de 2022, o preço de petróleo nos mercados internacionais tem vindo a descer de forma gradual, conforme figura acima. Este facto tem provocado:

**a)** Um deslocamento da oferta agregada de curto prazo (curva AS) para a esquerda (ou seja, para cima).

**b)** Um aumento da procura agregada (curva AD), deslocando a mesma para cima.

**c)** Um deslocamento da oferta agregada de curto prazo (curva AS) para a direita (ou seja, para baixo).

**d)** Uma diminuição da procura agregada (curva AD), deslocando a mesma para baixo.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ d149e58c-7f68-4355-91eb-b4d73466188a
@bind q12 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 656019a7-57f2-42d8-918f-60f1996af241
md"""
Quando Paul Volcker assumiu o cargo de novo Governador do Federal Reserve em 1979, a taxa de inflação ultrapassava os 10%. Em 1982, a taxa de desemprego disparou para 9,7% e a inflação caiu para 6.2%. Qual das seguintes opções é uma descrição apropriada do mecanismo por detrás da desinflação de Volcker?

**a)** A curva AD provavelmente deslocou-se para a esquerda devido à política monetária menos restritiva que explica a redução da taxa de inflação entre 1979 e 1982.

**b)** Devido à política monetária mais restritiva, hiato do produto (output gap) tornou-se negativo, o que explica o aumento da taxa de desemprego entre 1979 e 1982.

**c)** Em 1982, é provável que o produto agregado de equilíbrio fosse superior do que o potencial, levando a curva AS a deslocar-se para a esquerda para o eliminar, o que explica a redução da taxa de desemprego e a redução adicional da inflação entre 1982 e 1986.

**d)** Ao diminuir a Federal Funds Rate, a Reserva Federal acelerou a economia e conseguiu cortar a inflação pela metade em 1982 ao custo de um aumento substancial na taxa de desemprego, causando uma recessão.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 36490f8f-c8fc-40bf-b2a7-70426e0257ba
@bind q13 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c39dfe8b-97d2-4601-9fa8-0214aca1179a
md"""
Selecione a opção incorreta. Um choque permanente positivo na oferta agregada:

**a)** Torna a economia mais eficiente.

**b)** Promove decréscimos da taxa de inflação.

**c)** Aumenta o produto agregado no longo prazo.

**d)** Pode ser causado pelo desenvolvimento de uma tecnologia que aumenta a produtividade.

**e)** Aumenta a taxa de inflação..
"""


# ╔═╡ cfe4750f-2af3-42f7-a527-864b56d41733
@bind q14 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c6b0c07b-942b-4210-87dd-db00caafed1b
md"""
O preço do barril de petróleo duplicou entre 2007 e meados de 2008. Para piorar a situação, uma crise financeira atingiu a economia dos Estados Unidos a partir de agosto de 2007. Qual das opções a seguir é uma descrição apropriada do mecanismo que teria ocorrido?

**a)** A crise financeira teria levado a uma forte contração na despesa privada, deslocando a curva AD para a direita.

**b)** O aumento do preço do petróleo teria imediatamente deslocado a curva AS para a direita.

**c)** A crise financeira teria levado a um forte aumento despesa privada, deslocando a curva AD para a esquerda.

**d)** Mudanças nas curvas AD e AS ocorreram no curto prazo, mas desde que nenhum dos choques tenha tido impacto no produto potencial, o desemprego não teria sido afetado no longo prazo.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 9fbf9a0f-759a-4ee8-af34-982779e0e5ee
@bind q15 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ d733cdb8-c84a-4844-bca7-89e4a2ea83bd
md"""
A Lei do Plano de Resgate Americano de 2021 é uma lei de estímulo económico de 1.9 triliões de dólares (cerca de 10% do PIB) aprovada pelo Congresso dos Estados Unidos e promulgada pelo Presidente Joe Biden em 11 de Março de 2021. Porque razão o Presidente dos EUA promulgou esta lei?

**a)** Para contrair a procura agregada, a qual tinha aumentado imenso devido ao Covid19.

**b)** Para estimular a procura agregada, a qual tinha caído a pique devido ao Covid19.

**c)** Para contrair a oferta agregada, a qual tinha aumentado imenso devido ao Covid19.

**d)** Para contrair a inflação, a qual tinha atingido valores extremamente altos devido ao Covid19.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 7981e102-3cf1-4ae1-ae94-c1904d636641
@bind q16 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b7f5557d-6384-478b-988e-926bdc96e4e7
md"""
Um choque de oferta temporário negativo terá como efeito de longo prazo:

**a)** Valores de inflação e produto agregado iguais aos iniciais.

**b)** Valor de inflação diferente do inicial mas de produto agregado igual ao inicial.

**c)** Valor de inflação igual ao inicial mas de produto agregado diferente do inicial.

**d)** Valores de inflação e produto agregado diferentes dos iniciais.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 3973a512-fc1a-4dbd-af86-159172e5cd3e
@bind q17 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c4be74e5-03c3-4781-a684-765ebc529209
md"""
`ΔĀ5b = `$(@bind ΔĀ5b Slider(-1.0:0.1:1.0, default=0.0, show_value=true))
"""

# ╔═╡ 1ec91298-655c-4fa3-8c69-6fe281dec2f9
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	πd_max5_ΔĀ5 = ((Ā5 .+ ΔĀ5b) ./ (λ5 .* ϕ5)) .- r̄5 ./ λ5 # New max value of the AD function	
	πd5_ΔĀ5 = πd_max5_ΔĀ5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5_ΔĀ5) # New AD function
	
	trace9_0 = scatter(; x = [10,10] , y = [-7,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))
	trace9_4 = scatter(; x = Y5_ΔĀ5, y = πd5_ΔĀ5, mode="lines" , line_color = "Magenta", 
					line_width = "3", name  = "AD2")		
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end



# ╔═╡ 183dd55f-b4f2-4645-b427-f2b56365f317
md"""
As figuras acima representam o equilíbrio macroeconómico inicial. Suponha que o governo decide _aumentar_ as despesas públicas em + 0.3 triliões de dólares.  Usando o slider `ΔĀ5b` e as figuras, quais dos valores abaixo correspondem ao novo equilíbrio de _longo prazo_?

**a)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**b)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**c)** $\pi=1.5\% \ \  , \ \ Y = 9.8 \ \ , \ \ r=1.5\% \ \ , \ \ i = 3\%$

**d)** $\pi=5\% \ \  , \ \ Y = 10 \ \ , \ \ r=3\% \ \ , \ \ i = 8\%$

**e)** Nenhuma das anteriores.
"""


# ╔═╡ c707b9f9-19a9-4eae-8d97-0d2441dd8e61
@bind q18 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 479988ae-429b-41d2-8385-4c692fd62ec5
md"""
`Yp_shock = `$(@bind Yp_shock Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 3d4ba3e0-45e5-4c33-9f1c-9def0144b1cb
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shock) + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	trace9_0 = scatter(; x = [10+Yp_shock,10+Yp_shock], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))	
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end


# ╔═╡ 0ac221d2-e690-4c16-93d6-770cec789ec6
md"""
As figuras acima representam o equilíbrio macroeconómico inicial. Suponha que há um choque permanente sobre a oferta, de tal forma que o PIB potencial aumenta em +0.6 triliões de dólares. Usando o slider ` Yp_shock` para representar este choque, quais dos valores abaixo correspondem ao novo equilíbrio de _longo prazo_?

**a)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**b)** $\pi=1\% \ \  , \ \ Y = 10.6 \ \ , \ \ r=1\% \ \ , \ \ i = 2\%$

**c)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**d)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 9f263f69-8d7b-4146-ad22-f5e601855eef
@bind q19 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3c693419-e1da-49b8-b6c2-23287a42ecc7
md"""
Assuma que a economia se encontra num equilíbrio de longo prazo. Se se der um choque negativo sobre a procura agregada e o Banco Central quiser estabilizar a atividade económica antes do mecanismo de auto-correção atuar:

**a)** Terá de aceitar um valor de inflação mais elevado que o inicial.

**b)** A taxa de juro real de equilíbrio de longo prazo será igual à verificada antes do choque.

**c)** Terá de aceitar um valor de inflação mais reduzido que o inicial.

**d)** A taxa de juro real de equilíbrio de longo prazo será diferente.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 78a5cda4-f9f7-4ca7-aa05-ceb9b338c5b8
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 4222da75-5ad0-4a41-bfa3-10749bcc994c
md"""
Em meados da década de 1990, a internet começou a ser amplamente adotada com aumentos maciços de produtividade. Qual das opções é uma descrição apropriada do mecanismo por detrás desse choque de oferta?

**a)** A transição de uma economia pré-internet para uma economia da internet custou caro inicialmente. Assim, a curva AS provavelmente deslocou-se para a esquerda e o desemprego provavelmente aumentou no curto prazo.

**b)** Um hiato do produto (output gap) negativo terá resultado no curto prazo, mas foi eliminado através da deslocação da LRAS para a direita, o que é uma explicação provável para a diminuição da taxa de inflação na década de 1990.

**c)** Um hiato do produto (output gap) positivo terá resultado no curto prazo, mas foi eliminado através da deslocação da LRAS para a direita, o que é uma explicação provável para a diminuição da taxa de inflação na década de 1990.

**d)** O consequente aumento da capacidade produtiva levou ao deslocamento à direita do LRAS, o que é uma explicação provável para o declínio prolongado da taxa de desemprego na década de 1990.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ ed3584d5-ec46-4a40-9bc9-f4ab57601b4d
@bind q21 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f639b432-922a-4e0d-abef-1c23eefd3834
md"""
Os dois grandes objetivos que Reserva Federal Americana (Fed) deverá alcançar são:

**a)** Uma inflação de 5% e taxas de juro positivas.

**b)** Uma inflação de 4% e o máximo nível emprego possível.

**c)** Uma inflação de 2% e o máximo nível de emprego possível.

**d)** A inflação não é uma preocupação do Fed.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 65ff5d06-bc16-4c4d-a8ab-08607ad80966
@bind q22 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ fcc8673b-1904-4260-91eb-a24e9f899645
md"""
`Yp_shockb = `$(@bind Yp_shockb Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ dc32cafe-1398-4786-8143-3f32affe3c59
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shockb) + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	trace9_0 = scatter(; x = [10+Yp_shockb,10+Yp_shockb], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))	
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end


# ╔═╡ 4248014b-ce20-47d4-859a-88e382f968f2
md"""
As figuras acima representam o equilíbrio macroeconómico inicial. Suponha que há um choque permanente sobre a oferta, de tal forma que o PIB potencial diminui em --0.6 triliões de dólares. Usando o slider ` Yp_shockb` para representar este choque, quais dos valores abaixo correspondem ao novo equilíbrio de _longo prazo_?

**a)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**b)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**c)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**d)** $\pi=5\% \ \  , \ \ Y = 9.4 \ \ , \ \ r=3\% \ \ , \ \ i = 8\%$

**e)** Nenhuma das anteriores.
"""


# ╔═╡ dc479ecd-1183-4372-b734-7d21a3ddd078
@bind q23 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 959d9848-3c0e-46bf-8f9f-76ca95c7c053
begin	
	Ā5 = 5.6 ;	λ5 = 0.5 ;	m5 = 2.0 ;	ϕ5 = 0.3 ;	r̄5 = 0.5 		   	# Demand	
	γ5 = 4.0;	Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 					# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       							# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5           							# The AS curve y-axis' intercept
end;

# ╔═╡ cd1c3f2b-ac46-4bae-88c2-9af6a10db81b
md"""
Considere as quatro equações fundamentais do modelo macroeconómico estudado:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[3mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

Estando a informação sobre variáveis exógenas e parâmetros já inserida na célula acima, o equilíbrio macroeconómico será dado por:

**a)** $\pi=3.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=2\% \ \ , \ \ i = 5\%$

**b)** $\pi=5.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i =0.5\%$

**c)** $\pi=10\% \ \  , \ \ Y = 3 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5\%$

**d)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2\% \ \ , \ \ i = 5\%$

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 3a82d5b9-dba1-4aac-ad0d-034a17f5d97a
# Célula livre para cálculos

# ╔═╡ adaed021-9d2f-4a94-9a1a-c85951f76f04
# Célula livre para cálculos

# ╔═╡ b5c2be3e-3d0a-48ca-b6b8-8854b9cbd454
# Célula livre para cálculos

# ╔═╡ eeaa812e-8325-4b3d-9793-432ca6745c96
@bind q24 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 733936c5-ac90-4067-a7f5-aaa5fc0609fe
md"""
A regra de política monetária conhecida por “Taylor Rule” tem, como objetivo direto, ajudar o banco central a:

**a)** Controlar o PIB.

**b)** Controlar a taxa de desemprego.

**c)** Controlar a taxa de inflação.

**d)** Evitar falências de bancos.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 0aa10c63-4f4c-4090-a768-252ed42b63a7
@bind q25 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c397de26-5d7e-4e78-aead-b505200abd12
md"""
Estagnação secular, num contexto de ZLB (Zero Lower Bound), reflete-se em que cenário?

**a)** A procura agregada sofreu um choque negativo, ficando presa num ponto em que o produto agregado é inferior ao que a economia pode produzir de forma eficiente.

**b)** A procura agregada sofreu um choque positivo, ficando presa num ponto em que o produto agregado é inferior ao que a economia pode produzir de forma eficiente.

**c)** A oferta agregada sofreu um choque negativo, ficando presa num ponto em que o produto agregado é inferior ao que a economia pode produzir de forma eficiente.

**d)** A oferta agregada sofreu um choque positivo, ficando presa num ponto em que o produto agregado é inferior ao que a economia pode produzir de forma eficiente.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ a32c244d-6154-4afd-a710-8919ced949a5
@bind q26 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3358f7c3-5c9e-4e66-966a-4290637d1f97
md"""
A regra de Taylor para a taxa de juro nominal depende:

**a)** Negativamente da taxa de inflação e positivamente da taxa de inflação objetivo (target).

**b)** Negativamente do produto agregado e positivamente do protudo potencial.

**c)** Positivamente da taxa de desemprego e negativamente da taxa de desemprego natural.

**d)** Positivamente da taxa de juro real natural.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ d4c7c94c-0f49-42f6-9cfd-e4ea72b418c5
@bind q27 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a668d6cd-88e0-4667-9002-2c13fbd8ccaf
html"""<img src="https://vivaldomendes.org/images/Tests/AD_ZLB.png", style="width:500px"/>"""

# ╔═╡ 4a5fd6ae-51b8-46bd-82b7-987412140bec
md"""
A figura acima mostra a curva AD com os dois troços, separados pela linha do “Zero Lower Bound” (ZLB). Olhando para a figura, qual a razão que leva os economistas a dizerem que na zona do ZLB “a economia fica de pernas para o ar”?

**a)** Porque não conseguimos explicar nada de forma lógica.

**b)** Porque o PIB e a inflação passam a não estar relacionados.

**c)** Porque uma redução de 1% na inflação na zona normal, levará a um aumento do PIB; enquanto que a mesma redução na zona do ZLB levará a uma redução do PIB.

**d)** Porque o banco central deixa de se preocupar com a inflação.

**e)** Nenhuma das anteriores. 
"""


# ╔═╡ 0d650c44-9ef0-49e6-92c0-db4e362fdd16
@bind q28 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e52056bb-02f7-422f-8909-bff74c07fe51
md"""
O que é a situação que, do ponto de vista económico, é conhecida como o “Zero Lower Bound” (ou ZLB)?

**a)** É quando a taxa de inflação não pode descer abaixo de $0\%$.

**b)** É quando a taxa de desemprego não pode descer abaixo de $0\%$.

**c)** É quando a taxa de juro real não pode descer abaixo de $0\%$.

**d)** É quando a taxa de juro nominal não pode descer abaixo de $0\%$.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ c78792cf-9a56-472a-a2fe-146102e0cb7d
@bind q29 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ fce3a58c-c8e1-4387-b0ae-744828ceacdd
md"""
Se a taxa de inflação objetivo (target) é igual a 2%, a inflação atual é igual a 2%, e o hiato do produto (output gap) é igual a zero, então de acordo com a regra de Taylor (diferente do Princípio de Taylor), a Fed Funds rate deve ser:

**a)** 0

**b)** 0,02

**c)** 0,04

**d)** 0,03

**e)** Não existem informações suficientes para responder à questão.
"""


# ╔═╡ ff8233e6-6b25-46aa-90bd-9da210207fde
@bind q30 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 713452a5-156d-498d-8fa8-a1022b9fbb02
md"""
“O BCE considera que a melhor forma de manter a estabilidade de preços é através do objetivo de uma inflação de $2\%$ (“target”). Este objetivo é _simétrico_, o que significa que desvios negativos e positivos da inflação em relação ao objetivo são igualmente indesejáveis"". Qual a razão que levou BCE a mudar a sua política para “desvios simétricos”?

**a)** Porque, caso contrário, a taxa de inflação na Zona Euro estaria tendencialmente sempre abaixo dos $2\%$.

**b)** Porque o BCE, não sabendo muito bem o que fazer, assim decidiu.

**c)** Porque a Comissão Europeia assim decidiu.

**d)** Porque, caso contrário, a taxa de inflação na Zona Euro estaria tendencialmente sempre acima dos $2\%$.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 729a65fd-3e54-4157-a0f1-09e8414eef64
@bind q31 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 83a40c45-a611-42d4-bcab-9789a8cc9d0a
md"""
Após se atingir o ZLB (Zero Lower Bound), a taxa de juro real será:

**a)** Negativa, se a taxa de crescimento do nível geral de preços for negativa.

**b)** Positiva, se a taxa de crescimento do nível geral de preços for positiva.

**c)** Nula, se a taxa de crescimento do nível geral de preços for negativa.

**d)** Nula, se a taxa de crescimento do nível geral de preços for positiva.

**e)** Negativa, se a taxa de crescimento do nível geral de preços for positiva.
"""


# ╔═╡ 05ca8e1c-e370-41fd-b191-fda90a8427c6
@bind q32 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f8318e8b-f811-4215-82c4-5ab5b043388e
md"""
A dívida pública em percentagem do PIB tornar-se-á _insustentável_ ao longo do tempo se:

**a)** O défice primário em percentagem do PIB for sempre positivo.

**b)** A dívida pública inicial for muito elevada.

**c)** A taxa de juro paga pela emissão de dívida pública for inferior à taxa de crescimento do PIB real.

**d)** A taxa de juro paga pela emissão de dívida pública for superior à taxa de crescimento do PIB real.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 6199aa17-965c-4b74-b2da-8ab086ece24a
@bind q33 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b38bcc55-ef7e-4cd4-b32c-09a5dee51399
md"""
Que fator não influencia o nível de dívida pública?

**a)** O défice primário em percentagem do PIB.

**b)** A taxa de crescimento do PIB real.

**c)** A taxa de juro paga sobre a dívida pública.

**d)** A quantidade de reservas no passivo do Banco Central.

**e)** O défice antes do pagamento de juros.
"""


# ╔═╡ a1e10e97-e8b0-4f19-beb2-725ef28e2c13
@bind q34 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 803cce8c-908f-430e-a2bd-8257d97a030d
md"""
Selecione a opção incorreta sobre uma das duas principais escolas de pensamento económico.

**a)** Os economistas Keynesianos consideram que existem falhas significativas nos mercados (poder de mercados, bens públicos, externalidades, mercados incompletos).

**b)** Os economistas Clássicos consideram que o melhor cenário na economia é atingido sem intervenção do governo.

**c)** Os economistas Keynesianos consideram que o governo deve providenciar bens e serviços associados com as falhas de mercado, para além dos relacionados com a defesa, a justiça e a ordem.

**d)** Os economistas Clássicos consideram que os mercados funcionam sem falhas.

**e)** Os economistas Keynesianos e Clássicos são contra qualquer tipo de intervenção pelo governo.
"""


# ╔═╡ 4e7e768b-9dee-4d5c-97bd-db902a7164d7
@bind q35 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ dc2eb131-e60c-4b28-9f2b-1631654b7801
md"""
Selecione a opção incorreta. O multiplicador fiscal é mais elevado se:

**a)** O declive da curva AS for inferior.

**b)** A AS for horizontal.

**c)** A economia estiver no ZLB (Zero Lower Bound).

**d)** O declive da curva AS for vertical.

**e)** A sensibilidade da taxa de juro real à taxa de inflação for próxima de zero.
"""


# ╔═╡ eccb7a67-f33b-44b7-8ad0-596e800c6f1f
@bind q36 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 0f228516-84ec-4850-8502-766b8465396a
md"""
Em condições normais, o multiplicador fiscal:

**a)** Será maior se o declive da curva AS for também maior.

**b)** Será zero se a curva AS for horizontal.

**c)** Será maior se o declive da curva AS for menor.

**d)** Será bastante elevado se a curva AS for vertical.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 99a7c7bb-8be6-4012-b3b3-d7d1011a43d2
@bind q37 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 02f7d76c-9f1c-48b0-acf4-799473f5c618
md"""
Considere que a taxa de crescimento do PIB real é dada por $g$, que a taxa de juro real paga sobre a dívida pública é dada por $r_p$ e que o saldo primário do Governo é negativo. Selecione a opção correta.

**a)** Se $g>r_p$ , o nível de dívida pública é insustentável.

**b)** Se $g=r_p$ , o nível de dívida pública é sustentável.

**c)** Se $g<r_p$ , o nível de dívida pública é insustentável.

**d)** $g$ e $r_p$ têm pouco a ver com a sustentabilidade da dívida pública.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ c2ecc59f-6219-497f-a835-b19e6b30ac82
@bind q38 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 76d4698b-a9ef-4ddf-af3f-ceb0ee14cd6f
html"""<img src="https://vivaldomendes.org/images/Tests/multiplier1.png" style="width:600px"/>"""

# ╔═╡ 299264d2-59b3-498d-83e4-4521c2e3c3cf
md"""
A figura acima mostra três situações diferentes relativamente ao valor do multiplicador fiscal (“fiscal multiplier”). Qual corresponde à situação em que o multiplicador fiscal é mais elevado?

**a)** Caso 3.

**b)** Caso 0.

**c)** Caso 1.

**d)** Caso 2,

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 5ffa64f3-c53a-4c0d-aaef-9edead28de12
@bind q39 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 13c5238f-9a75-4dc6-a46f-d50b627b14e9
md"""
As três variáveis que condicionam a evolução da dívida pública em percentagem do PIB são:

**a)** A inflação, o desemprego e a taxa de juro real.

**b)** A inflação, o desemprego e a taxa de câmbio

**c)** O défice primário em percentagem do PIB, a taxa de juro real paga pela emissão de dívida pública, e a taxa de crescimento do PIB real.

**d)** O défice primário em percentagem do PIB, a taxa de juro real paga pela emissão de dívida pública, e a taxa de inflação.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ fcf6d14a-5591-4acf-b48c-2094983c047b
@bind q40 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ee59ecb9-a440-47ff-bbcd-d4a985676de0
md"""
!!! danger "Instruções finais"

	Concluiu a prova.

	O último passo é confirmar que quer **guardar as suas respostas**, através da **Checkbox depois desta caixa**. Ao carregar, será gerado um **ficheiro `.csv`** na mesma pasta onde está alojado este Notebook.

	**É esse ficheiro que deverá enviar à equipa docente.**

	Antes de enviar, certifique-se que a data/hora do ficheiro fazem sentido. **Só depois deve fechar o Notebook.**
"""

# ╔═╡ c17d3e59-cf96-48e7-a23e-697004030ab6
md"Confirmo que ao longo da prova procedi sempre de acordo com todas as **normas de ética e de integridade académicas**, isto é, sem qualquer recurso ilícito à luz das normas do ISCTE e, em particular, da Unidade Curricular de Macroeconomia I, pelo que quero **guardar as minhas respostas** a fim de as remeter à equipa docente para o meu trabalho ser devidamente avaliado. $(CheckBox(default=false))"

# ╔═╡ 53b9e1ed-3f82-4fca-94b1-19c4c9f09120
md"---"

# ╔═╡ 81e65a11-a675-4696-913d-2c0cb8f9f671
md"## Células auxiliares"

# ╔═╡ f0728dc6-97fc-4b41-a6ab-fd73b7fe0a5a
md"### Packages"

# ╔═╡ c855ae34-f784-4abf-b7f0-126f24ed1ba6
md"### CSS code"

# ╔═╡ 4723ffc0-026f-4fee-ae3a-51ab2e080798
html"""
<link href="https://fonts.googleapis.com/css?family=Montserrat:300,300italic,700,700italic" rel="stylesheet">

<style>
	main {
		max-width: 1200px;
		padding: 5%;
        display: block !important;
        margin-left: auto !important;
        margin-right: auto !important;
        user-select: none !important;
         -webkit-user-select: none !important;
         -moz-user-select: none !important;
         -ms-user-select: none !important;
    }
	pluto-output {
		font-family: "Montserrat" !important;
		font-size: 1em;
		line-height: 1.5;
	}
	.plutoui-toc {
		font-family: "Montserrat" !important;
		font-size: 90%;
	}
	.admonition-title {
		font-family: "Montserrat" !important;
	}
	pluto-output h1, h2, h3 {
		font-family: "Montserrat" !important;
		border: none !important;
	}
	pluto-output h1 {
		font-size: 1.8em !important;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
	}
	pluto-output h2 {
		font-size: 1.5em !important;
		margin-top: 1.8em;
		margin-bottom: 1em;
	}
	pluto-output h3 {
		font-size: 1.3em !important;
		margin-top: 1.5em;
		margin-bottom: 1em;
	}
	img:not(picture *) {
		width: 80%;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	title {
		font-size: 2.2em;
		display: block;
		font-weight: bold;
		text-align: left;
		margin: 1.5em 0 0em 0;
}
	subtitle {
		font-size: 1.6em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	author {
		display: block;
		text-align: left;
		padding-bottom: 0.8em;
		border-bottom: 3px solid !important;
}
	email {
		display: block;
		text-align: left;
		margin: 0 0 2.5em 0;
}
	semester {
		font-size: 1.3em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	.admonition-title {
		font-size: 125%;
	}
	ol {
		list-style-type: lower-alpha;
	}
	li::marker {
		font-weight: bold;
	}
	li {
		margin-top: 1em !important;
		margin-bottom: 1em !important;
	}
	.small {
		font-size: 80%;
	}
	.centered-image {
		display: block;
		margin-left: auto;
		margin-right: auto;
		margin-top: 1em;
		margin-bottom: 1em;
		width: 90%;
	}
	details {
		font-size: 80%;
		margin-left: 3em;
	}
	summary {
		font-size: 125%;
		margin-left: -2.2em;
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	input[type="checkbox"] {
		transform: scale(1.5);
	}
	textarea, input[type="text"] {
		font-family: "Montserrat" !important;
		font-size: 0.85em !important;
		line-height: 1.5;
	}
    pluto-cell>button,pluto-input>button,pluto-shoulder {
    display: none !important;
    }
</style>
"""

# ╔═╡ 0be9b5bf-5adb-4ba3-8a04-27db34959e3d
md"### Internal functions"

# ╔═╡ 293b09e0-fd78-4421-ae15-6c8f962cadb1
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Por favor selecione uma resposta.*

		---
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Correto!"

			---
			"""
		else	
			md"""
			!!! danger "👎 Resposta errada"
				
				Tente outra vez. **Mas estude primeiro!!!** 😡

			---
			"""
		end
	end
end;

# ╔═╡ a152b926-f764-469e-9c1b-410c2e89e3cb
tchanã(q01,"a)")

# ╔═╡ 51703aa7-1b20-41f9-a38f-589b239c7c46
tchanã(q02,"d)")

# ╔═╡ ce5330da-fb1e-4203-b96d-9cee9853a7da
tchanã(q03,"d)")

# ╔═╡ d703cdef-0f08-48e6-8792-319995f84fcb
tchanã(q04,"b)")

# ╔═╡ 9702997a-6593-42cd-a4c2-a47ee5cdd75f
tchanã(q05,"d)")

# ╔═╡ 8b474d48-b187-4716-b01e-fb451bcced63
tchanã(q06,"d)")

# ╔═╡ 9d9eaa5d-57d6-41fc-9a2b-2d8ca74f038b
tchanã(q07,"c)")

# ╔═╡ 0db12097-c208-4bb1-a7c5-1f850e3af955
tchanã(q08,"d)")

# ╔═╡ 824332fd-bc74-41ae-97a1-4ce861709ce0
tchanã(q09,"b)")

# ╔═╡ e06ba917-6c4e-4ff3-91be-71265e2cfd5b
tchanã(q10,"e)")

# ╔═╡ 822d2fe6-b794-45f5-902f-da167018e50f
tchanã(q11,"b)")

# ╔═╡ 32448823-c978-4f5d-9f6d-f189e133eb4c
tchanã(q12,"c)")

# ╔═╡ c4a395af-7788-4629-9565-071b9c4d1005
tchanã(q13,"b)")

# ╔═╡ 0ffa6550-e65d-4b2d-9f61-5c55c64fc26c
tchanã(q14,"e)")

# ╔═╡ 18e7a31b-2c16-4eda-8abb-942e359d3f45
tchanã(q15,"d)")

# ╔═╡ 896ae13c-09f8-4607-b3d7-24b0f84150cb
tchanã(q16,"b)")

# ╔═╡ 9cc16770-7506-455d-8351-054b26f058ce
tchanã(q17,"a)")

# ╔═╡ 275c3fe1-0abb-4b6d-8461-1a1101f42475
tchanã(q18,"d)")

# ╔═╡ 9b8698a4-58d5-458d-b179-a1f061bdfd20
tchanã(q19,"b)")

# ╔═╡ 710ac186-87cf-4ef2-aaab-095e80ae6058
tchanã(q20,"d)")

# ╔═╡ 6132fd35-fc23-4230-8c41-10eeb5fadef7
tchanã(q21,"d)")

# ╔═╡ 25a62685-66ba-462e-b90d-b6452d2ac992
tchanã(q22,"c)")

# ╔═╡ 163822b0-c5d4-476c-a710-f6d747e48cfe
tchanã(q23,"d)")

# ╔═╡ cf004b55-4000-44e0-9627-50ccdd188c61
tchanã(q24,"d)")

# ╔═╡ cf187e79-35f9-4399-83b6-a22b36d2b8c9
tchanã(q25,"c)")

# ╔═╡ 665ac3b2-63de-4e78-8cb4-6de9bfa4ead3
tchanã(q26,"a)")

# ╔═╡ c1b20153-9059-42af-a5d0-f268fdbad58b
tchanã(q27,"d)")

# ╔═╡ 082c1a5a-1a16-4d5c-9fc5-54001ab71cd3
tchanã(q28,"c)")

# ╔═╡ caf64d1f-990a-4644-b186-3daac02bd3d1
tchanã(q29,"d)")

# ╔═╡ 4b941c78-e8cc-4b83-af21-186b6a6e6cde
tchanã(q30,"e)")

# ╔═╡ c89fa1f4-4a20-4f44-b632-bcba651f047d
tchanã(q31,"a)")

# ╔═╡ 0c9e8b47-6035-4b4a-8dda-27317844be2c
tchanã(q32,"e)")

# ╔═╡ bd951b0b-3524-46de-9de2-92f1b2b64c09
tchanã(q33,"d)")

# ╔═╡ 7cf9e3a2-6884-4602-91b9-d4d1264f2fa9
tchanã(q34,"d)")

# ╔═╡ 1b12bddc-9603-47b2-a3de-743c010ab5a0
tchanã(q35,"e)")

# ╔═╡ a299e8c4-8915-43c5-a678-06c9a8109692
tchanã(q36,"d)")

# ╔═╡ 82236c3b-60e7-42fb-8bfa-51c83e7bd5a5
tchanã(q37,"c)")

# ╔═╡ e6676b50-e2bb-4586-8083-6ecdbde45f6a
tchanã(q38,"c)")

# ╔═╡ bfed4976-1c8e-4316-be93-386fb347aae6
tchanã(q39,"a)")

# ╔═╡ b4c2ff80-3ee5-4010-a39e-2065b0689b82
tchanã(q40,"c)")

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.10"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
NLsolve = "~4.5.1"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoTeachingTools = "~0.2.11"
PlutoUI = "~0.7.51"
StatsBase = "~0.34.0"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.9.3"
manifest_format = "2.0"
project_hash = "579384cc5faf1a9c26202f2f8cd4727ad787fa94"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "91bd53c39b9cbfb5ef4b015e8b582d344532bd0a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.2.0"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "76289dc51920fdc6e0013c872ba9551d54961c24"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "3.6.2"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra", "Requires", "SparseArrays", "SuiteSparse"]
git-tree-sha1 = "f83ec24f76d4c8f525099b2ac475fc098138ec31"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.4.11"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "44dbf560808d49041989b8a96cae4cffbeb7966a"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.11"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "a1296f0fe01a4c3f9bf0dc2934efbf4416f5db31"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.4"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "02aa26a4cf76381be7f66e020a3eddeb27b0a092"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "d9a8f86737b665e15a9641ecbac64deef9ce6724"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.23.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.Compat]]
deps = ["UUIDs"]
git-tree-sha1 = "e460f044ca8b99be31d35fe54fc33a5c33dd8ed7"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.9.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+0"

[[deps.ConstructionBase]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "fe2838a593b5f776e1597e086dcd47560d94e816"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.3"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "8da84edb865b0b5b0100c0666a9bc9a0b71c553c"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.15.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "3dbd312d370723b6bb43ba9d02fc36abade4518d"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.15"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "b6def76ffad15143924a2199f72a5cd883a2e8a9"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.9"
weakdeps = ["SparseArrays"]

    [deps.Distances.extensions]
    DistancesSparseArraysExt = "SparseArrays"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "Setfield", "SparseArrays"]
git-tree-sha1 = "c6e4a1fbe73b31a3dea94b1da449503b8830c306"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.21.1"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "cf0fe81336da9fb90944683b8c41984b08793dad"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.36"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "7e5d6779a1e09a36db2a7b6cff50942a0a7d0fca"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.5.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "81dc6aefcbe7421bd62cb6ca0e700779330acff8"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.25"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.Latexify]]
deps = ["Formatting", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Printf", "Requires"]
git-tree-sha1 = "f428ae552340899a935973270b8d98e5a31c49fe"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.1"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "7bbea35cec17305fc70a0e5b4641477dc0789d9d"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.2.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "7d6dd4e9212aebaeed356de34ccf262a3cd415aa"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.26"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "60168780555f3e663c536500aa790b6368adc02a"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "2.3.0"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "9ee1618cbf5240e6d4e0371d6f24065083f60c48"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.11"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.10.11"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "0877504529a3e5c3343c6f8b4c0381e57e4387e4"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.0.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.21+4"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+0"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "2e73fe17cac3c62ad1aebe70d44c963c3cfdc3e3"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.2"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "716e24b21538abc91f6205fd1d8363f39b442851"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.7.2"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.9.2"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "542de5acb35585afcf202a6d3361b430bc1c3fbd"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.13"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "e47cd150dbe0443c3a3651bc5b9cbd5576ab75b7"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.52"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "03b4c25b43cb84cee5c90aa9b5ea0a78fd848d2f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.0"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "ee094908d720185ddbdc58dbe0c1cbe35453ec7a"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.7"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "Distributed", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "Pkg", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "1e597b93700fa4045d7189afa7c004e0584ea548"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.5.3"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "04bdff0b09c65ff3e06a05e3eb7b120223da3d39"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "c60ec5c62180f27efea3ba2908480f8055e17cee"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "e2cfc4012a19088254b3950b85c3c1d8882d864d"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.3.1"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "36b3d696ce6366023a0ea192b4cd442268995a0d"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.2"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.9.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "75ebe04c5bed70b91614d684259b661c9e6274a4"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.34.0"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.SuiteSparse]]
deps = ["Libdl", "LinearAlgebra", "Serialization", "SparseArrays"]
uuid = "4607b0f0-06f3-5cda-b6b1-a6196a1729e9"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "Pkg", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "5.10.1+6"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "9a6ae7ed916312b41236fcef7e0af564ef934769"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.13"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "b7a5e99f24892b6824a954199a45e9ffcc1c70f0"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.0"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+0"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─1f1076c3-5aca-4037-8d45-6a23872ceda4
# ╟─680433b3-98f7-437c-9026-9533c9b4f61e
# ╟─66e21396-7e88-4913-b3ce-b6b4f5f9656a
# ╟─efc03349-cad1-482c-a4ee-d410a66b36e8
# ╟─7241544e-5d6d-4897-bae3-843dc1eb170e
# ╟─4ad6bdf1-3029-43e5-9b0f-cff6525ffe94
# ╟─ca0e61f0-f955-11ed-00af-1f63977dd3de
# ╟─584268fb-7d05-4ec1-aced-acdd66e7d7f4
# ╟─a152b926-f764-469e-9c1b-410c2e89e3cb
# ╟─5fd57b29-069d-4a2e-872e-bb9b9bbe1ff0
# ╟─5117e0b7-07f2-440e-9edf-098dc77b128f
# ╟─51703aa7-1b20-41f9-a38f-589b239c7c46
# ╟─7f860aaa-b1bc-4ed7-a9aa-1b07e07cadc3
# ╟─4cf1f4da-e5e3-4fa8-a15c-41bdcc8d5c78
# ╟─ce5330da-fb1e-4203-b96d-9cee9853a7da
# ╟─5265edb5-ec8b-434c-bef2-1b45dbd143b7
# ╟─29889baf-6d1a-45e7-8af4-ea9238715c47
# ╟─617482da-379f-448a-b021-8a2d0a80416e
# ╟─d703cdef-0f08-48e6-8792-319995f84fcb
# ╟─8a796898-03c2-4b93-98d8-bb95ae46e45c
# ╟─a8f403a7-6d38-435e-8307-22388809b267
# ╟─9702997a-6593-42cd-a4c2-a47ee5cdd75f
# ╟─c0147dfb-3abc-4ef3-9d3d-215cf69deb02
# ╟─5c40e68a-da32-4bd0-af8e-c3141318d0a7
# ╟─a02a491a-ec0f-4ef9-b7c5-e31194f43c8c
# ╟─8b474d48-b187-4716-b01e-fb451bcced63
# ╟─c0109b03-2c2f-4d93-b74c-b643c986f545
# ╟─6925cd02-56f1-48c7-9b02-c3538e101f4d
# ╟─9d9eaa5d-57d6-41fc-9a2b-2d8ca74f038b
# ╟─b46aa2bf-8576-44f4-b056-59b5edd8c3dc
# ╟─8a0cf087-7aff-4a17-863e-ee39015ce8a8
# ╟─0db12097-c208-4bb1-a7c5-1f850e3af955
# ╟─9f9e760d-c7d7-420e-8ac2-cf6f26ee837b
# ╟─19e73b89-d4f1-4e82-8ae7-5db98ab7e8c7
# ╟─824332fd-bc74-41ae-97a1-4ce861709ce0
# ╟─70e53de6-c41a-472e-9140-dfcdf28598c9
# ╟─7a93da9a-3380-46f9-944e-83c5ed800c55
# ╟─e06ba917-6c4e-4ff3-91be-71265e2cfd5b
# ╟─649703b9-c02b-4ee0-955a-e79abb826988
# ╟─06d66a09-5a55-4a00-b024-6bf84e2f77ad
# ╟─822d2fe6-b794-45f5-902f-da167018e50f
# ╟─ec48a6a7-1565-4075-a933-d029197c6922
# ╟─0183c27d-9e10-4511-95df-067259f0036a
# ╟─d149e58c-7f68-4355-91eb-b4d73466188a
# ╟─32448823-c978-4f5d-9f6d-f189e133eb4c
# ╟─656019a7-57f2-42d8-918f-60f1996af241
# ╟─36490f8f-c8fc-40bf-b2a7-70426e0257ba
# ╟─c4a395af-7788-4629-9565-071b9c4d1005
# ╟─c39dfe8b-97d2-4601-9fa8-0214aca1179a
# ╟─cfe4750f-2af3-42f7-a527-864b56d41733
# ╟─0ffa6550-e65d-4b2d-9f61-5c55c64fc26c
# ╟─c6b0c07b-942b-4210-87dd-db00caafed1b
# ╟─9fbf9a0f-759a-4ee8-af34-982779e0e5ee
# ╟─18e7a31b-2c16-4eda-8abb-942e359d3f45
# ╟─d733cdb8-c84a-4844-bca7-89e4a2ea83bd
# ╟─7981e102-3cf1-4ae1-ae94-c1904d636641
# ╟─896ae13c-09f8-4607-b3d7-24b0f84150cb
# ╟─b7f5557d-6384-478b-988e-926bdc96e4e7
# ╟─3973a512-fc1a-4dbd-af86-159172e5cd3e
# ╟─9cc16770-7506-455d-8351-054b26f058ce
# ╟─c4be74e5-03c3-4781-a684-765ebc529209
# ╟─1ec91298-655c-4fa3-8c69-6fe281dec2f9
# ╟─183dd55f-b4f2-4645-b427-f2b56365f317
# ╟─c707b9f9-19a9-4eae-8d97-0d2441dd8e61
# ╟─275c3fe1-0abb-4b6d-8461-1a1101f42475
# ╟─479988ae-429b-41d2-8385-4c692fd62ec5
# ╟─3d4ba3e0-45e5-4c33-9f1c-9def0144b1cb
# ╟─0ac221d2-e690-4c16-93d6-770cec789ec6
# ╟─9f263f69-8d7b-4146-ad22-f5e601855eef
# ╟─9b8698a4-58d5-458d-b179-a1f061bdfd20
# ╟─3c693419-e1da-49b8-b6c2-23287a42ecc7
# ╟─78a5cda4-f9f7-4ca7-aa05-ceb9b338c5b8
# ╟─710ac186-87cf-4ef2-aaab-095e80ae6058
# ╟─4222da75-5ad0-4a41-bfa3-10749bcc994c
# ╟─ed3584d5-ec46-4a40-9bc9-f4ab57601b4d
# ╟─6132fd35-fc23-4230-8c41-10eeb5fadef7
# ╟─f639b432-922a-4e0d-abef-1c23eefd3834
# ╟─65ff5d06-bc16-4c4d-a8ab-08607ad80966
# ╟─25a62685-66ba-462e-b90d-b6452d2ac992
# ╟─fcc8673b-1904-4260-91eb-a24e9f899645
# ╟─dc32cafe-1398-4786-8143-3f32affe3c59
# ╟─4248014b-ce20-47d4-859a-88e382f968f2
# ╟─dc479ecd-1183-4372-b734-7d21a3ddd078
# ╟─163822b0-c5d4-476c-a710-f6d747e48cfe
# ╠═959d9848-3c0e-46bf-8f9f-76ca95c7c053
# ╟─cd1c3f2b-ac46-4bae-88c2-9af6a10db81b
# ╠═3a82d5b9-dba1-4aac-ad0d-034a17f5d97a
# ╠═adaed021-9d2f-4a94-9a1a-c85951f76f04
# ╠═b5c2be3e-3d0a-48ca-b6b8-8854b9cbd454
# ╟─eeaa812e-8325-4b3d-9793-432ca6745c96
# ╟─cf004b55-4000-44e0-9627-50ccdd188c61
# ╟─733936c5-ac90-4067-a7f5-aaa5fc0609fe
# ╟─0aa10c63-4f4c-4090-a768-252ed42b63a7
# ╟─cf187e79-35f9-4399-83b6-a22b36d2b8c9
# ╟─c397de26-5d7e-4e78-aead-b505200abd12
# ╟─a32c244d-6154-4afd-a710-8919ced949a5
# ╟─665ac3b2-63de-4e78-8cb4-6de9bfa4ead3
# ╟─3358f7c3-5c9e-4e66-966a-4290637d1f97
# ╟─d4c7c94c-0f49-42f6-9cfd-e4ea72b418c5
# ╟─c1b20153-9059-42af-a5d0-f268fdbad58b
# ╟─a668d6cd-88e0-4667-9002-2c13fbd8ccaf
# ╟─4a5fd6ae-51b8-46bd-82b7-987412140bec
# ╟─0d650c44-9ef0-49e6-92c0-db4e362fdd16
# ╟─082c1a5a-1a16-4d5c-9fc5-54001ab71cd3
# ╟─e52056bb-02f7-422f-8909-bff74c07fe51
# ╟─c78792cf-9a56-472a-a2fe-146102e0cb7d
# ╟─caf64d1f-990a-4644-b186-3daac02bd3d1
# ╟─fce3a58c-c8e1-4387-b0ae-744828ceacdd
# ╟─ff8233e6-6b25-46aa-90bd-9da210207fde
# ╟─4b941c78-e8cc-4b83-af21-186b6a6e6cde
# ╟─713452a5-156d-498d-8fa8-a1022b9fbb02
# ╟─729a65fd-3e54-4157-a0f1-09e8414eef64
# ╟─c89fa1f4-4a20-4f44-b632-bcba651f047d
# ╟─83a40c45-a611-42d4-bcab-9789a8cc9d0a
# ╟─05ca8e1c-e370-41fd-b191-fda90a8427c6
# ╟─0c9e8b47-6035-4b4a-8dda-27317844be2c
# ╟─f8318e8b-f811-4215-82c4-5ab5b043388e
# ╟─6199aa17-965c-4b74-b2da-8ab086ece24a
# ╟─bd951b0b-3524-46de-9de2-92f1b2b64c09
# ╟─b38bcc55-ef7e-4cd4-b32c-09a5dee51399
# ╟─a1e10e97-e8b0-4f19-beb2-725ef28e2c13
# ╟─7cf9e3a2-6884-4602-91b9-d4d1264f2fa9
# ╟─803cce8c-908f-430e-a2bd-8257d97a030d
# ╟─4e7e768b-9dee-4d5c-97bd-db902a7164d7
# ╟─1b12bddc-9603-47b2-a3de-743c010ab5a0
# ╟─dc2eb131-e60c-4b28-9f2b-1631654b7801
# ╟─eccb7a67-f33b-44b7-8ad0-596e800c6f1f
# ╟─a299e8c4-8915-43c5-a678-06c9a8109692
# ╟─0f228516-84ec-4850-8502-766b8465396a
# ╟─99a7c7bb-8be6-4012-b3b3-d7d1011a43d2
# ╟─82236c3b-60e7-42fb-8bfa-51c83e7bd5a5
# ╟─02f7d76c-9f1c-48b0-acf4-799473f5c618
# ╟─c2ecc59f-6219-497f-a835-b19e6b30ac82
# ╟─e6676b50-e2bb-4586-8083-6ecdbde45f6a
# ╟─76d4698b-a9ef-4ddf-af3f-ceb0ee14cd6f
# ╟─299264d2-59b3-498d-83e4-4521c2e3c3cf
# ╟─5ffa64f3-c53a-4c0d-aaef-9edead28de12
# ╟─bfed4976-1c8e-4316-be93-386fb347aae6
# ╟─13c5238f-9a75-4dc6-a46f-d50b627b14e9
# ╟─fcf6d14a-5591-4acf-b48c-2094983c047b
# ╟─b4c2ff80-3ee5-4010-a39e-2065b0689b82
# ╟─ee59ecb9-a440-47ff-bbcd-d4a985676de0
# ╟─c17d3e59-cf96-48e7-a23e-697004030ab6
# ╟─53b9e1ed-3f82-4fca-94b1-19c4c9f09120
# ╟─81e65a11-a675-4696-913d-2c0cb8f9f671
# ╟─f0728dc6-97fc-4b41-a6ab-fd73b7fe0a5a
# ╠═3eeeedf8-d228-4178-bfc5-710f46649c2a
# ╟─c855ae34-f784-4abf-b7f0-126f24ed1ba6
# ╟─4723ffc0-026f-4fee-ae3a-51ab2e080798
# ╟─0be9b5bf-5adb-4ba3-8a04-27db34959e3d
# ╟─293b09e0-fd78-4421-ae15-6c8f962cadb1
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
